DSHState<IteratorState, Result> class

Constructors

DSHState(IteratorState current)
const

Properties

current → IteratorState
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

done([Iterable<Result>? data]) DSHNextResultDone<IteratorState, Result>
next(Iterable<Result> data, IteratorState nextState) DSHNextResultNext<IteratorState, Result>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited