BaseAppLocale<E extends BaseAppLocale<E, T> , T extends BaseTranslations<E, T> > class
abstract
Similar to flutter locale but available without any flutter dependencies. Subclasses will be enums.
- Available extensions
Constructors
Properties
-
build
→ TranslationBuilder<
E, T> -
Gets a new translation instance.
LocaleSettings has no effect here.
Suitable for dependency injection and unit tests.
no setter
- countryCode → String?
-
no setter
- flutterLocale → Locale
-
Available on BaseAppLocale<
Returns the locale type of the flutter framework.BaseAppLocale, BaseTranslations> , provided by the ExtAppLocale extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String
-
no setter
- languageTag → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scriptCode → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sameLocale(
BaseAppLocale< BaseAppLocale, BaseTranslations> other) → bool -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited