RichPluralResolvers class

Rich plural resolvers

Constructors

RichPluralResolvers()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bridge({required num n, required PluralResolver resolver, TextSpan zero()?, TextSpan one()?, TextSpan two()?, TextSpan few()?, TextSpan many()?, TextSpan other()?}) TextSpan
The plural resolver for rich text. It uses the original resolver (which only handles strings) to determine which plural form should be used.