StringsRu class
Constructors
-
StringsRu.build({Map<
String, Node> ? overrides, PluralResolver? cardinalResolver, PluralResolver? ordinalResolver}) - You can call this constructor and build your own translation instance of this locale. Constructing via the enum AppLocale.build is preferred.
Properties
-
$meta
→ TranslationMetadata<
AppLocale, StringsEn> -
Metadata for the translations of
final
- genericLoadingError → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- retryButton → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → dynamic -
Access flat map
override