TranslationOverridesFlutter class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

rich(TranslationMetadata<BaseAppLocale, BaseTranslations> meta, String path, Map<String, Object> param) TextSpan?
Handler for overridden rich text. Returns a TextSpan if the path was successfully overridden. Returns null otherwise.
richContext<T>(TranslationMetadata<BaseAppLocale, BaseTranslations> meta, String path, Map<String, Object> param) TextSpan?
Handler for overridden rich context. Returns a TextSpan if the path was successfully overridden. Returns null otherwise.
richPlural(TranslationMetadata<BaseAppLocale, BaseTranslations> meta, String path, Map<String, Object> param) TextSpan?
Handler for overridden rich plural. Returns a TextSpan if the path was successfully overridden. Returns null otherwise.